from inspect import signature

class ArgTracker(dict):
    """This class tracks usage of function keyword arguments to detect ones that are never used."""

    def __init__(self, *args):
        super().__init__(*args)
        self.accessed = set()

    def __getitem__(self, key):
        self.accessed.add(key)
        return super().__getitem__(key)

    def get(self, key, default):
        self.accessed.add(key)
        return super().get(key, default)

    def checkArgs(self, fn):
        """Throw an exception if any argument was never used."""
        parameters = signature(fn).parameters
        for key in self:
            if key not in self.accessed:
                if key not in parameters or self[key] != parameters[key].default:
                    raise ValueError(f"The argument '{key}' was specified to {fn.__name__}() but was never used.")




# THIS FILE IS GENERATED FROM OPENMM SETUP.PY
short_version = '7.7.0'
version = '7.7.0'
full_version = '7.7.0.dev-130124a'
git_revision = '130124a3f9277b054ec40927360a6ad20c8f5fa6'
release = False
openmm_library_path = r'D:/bld/openmm_1646185643413/_h_env/Library/lib'

if not release:
    version = full_version
